@@ -15,7 +15,7 @@ Readonly::Array our @EXPORT_OK => qw(first_male first_female middle_female
 	last_male last_female middle_male middle_female name);
 
 # Version.
-our $VERSION = '0.01';
+our $VERSION = 0.02;
 
 # First and middle male names.
 our @first_male = our @middle_male = qw(
@@ -1287,11 +1287,11 @@ From Slovakia calendar.
 
 =item B<first_male()>
 
-Returns random fists name of male person.
+Returns random first name of male person.
 
 =item B<first_female()>
 
-Returns random fists name of female person.
+Returns random first name of female person.
 
 =item B<last_male()>
 
@@ -2132,7 +2132,9 @@ L<Readonly>.
 
 L<Mock::Person>,
 L<Mock::Person::CZ>,
+L<Mock::Person::EN>,
 L<Mock::Person::DE>,
+L<Mock::Person::SK::ROM>,
 L<Mock::Person::SV>,
 L<Mock::Person::RU>.
 
@@ -2152,6 +2154,6 @@ BSD license.
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
